@@ -14,14 +14,15 @@
 #' }
 #' @param pt A numeric vector of person-time at risk. If provided, \code{counts} must be a numeric vector of disease counts.
 #' @param reps Number of replications to run.
-#' @param seca.parms List defining the sensitivity of exposure classification among those with the outcome. The first argument provides the probability distribution function (uniform, triangular, trapezoidal, logit-logistic, or logit-normal) and the second its parameters as a vector. Logit-logistic and logit-normal distributions can be shifted by providing lower and upper bounds. Avoid providing these values if a non-shifted distribution is desired.
+#' @param seca.parms List defining the sensitivity of exposure classification among those with the outcome. The first argument provides the probability distribution function (uniform, triangular, trapezoidal, logit-logistic, logit-normal, or beta) and the second its parameters as a vector. Logit-logistic and logit-normal distributions can be shifted by providing lower and upper bounds. Avoid providing these values if a non-shifted distribution is desired.
 #' \enumerate{
-#' \item Constant: constant value,
-#' \item Uniform: min, max,
-#' \item Triangular: lower limit, upper limit, mode,
-#' \item Trapezoidal: min, lower mode, upper mode, max,
-#' \item Logit-logistic: location, scale, lower bound shift, upper bound shift,
-#' \item Logit-normal: location, scale, lower bound shift, upper bound shift.
+#' \item constant: constant value,
+#' \item uniform: min, max,
+#' \item triangular: lower limit, upper limit, mode,
+#' \item trapezoidal: min, lower mode, upper mode, max,
+#' \item logit-logistic: location, scale, lower bound shift, upper bound shift,
+#' \item logit-normal: location, scale, lower bound shift, upper bound shift,
+#' \item beta: alpha, beta.
 #' }
 #' @param seexp.parms List defining the sensitivity of exposure classification among those without the outcome.
 #' @param spca.parms List defining the specificity of exposure classification among those with the outcome.
@@ -48,18 +49,18 @@
 #' seca.parms = list("trapezoidal", c(.4, .45, .55, .6)),
 #' spca.parms = list("constant", 1))
 #' @export
-#' @importFrom stats binom.test median quantile qnorm runif
+#' @importFrom stats binom.test median quantile qnorm runif qbeta rbeta
 probsens.irr <- function(counts,
                          pt = NULL,
                          reps = 1000,
                          seca.parms = list(dist = c("constant", "uniform",
                                                "triangular", "trapezoidal",
-                                               "logit-logistic", "logit-normal"),
+                                               "logit-logistic", "logit-normal", "beta"),
                              parms = NULL),
                          seexp.parms = NULL,
                          spca.parms = list(dist = c("constant", "uniform",
                                                "triangular", "trapezoidal",
-                                               "logit-logistic", "logit-normal"),
+                                               "logit-logistic", "logit-normal", "beta"),
                              parms = NULL),
                          spexp.parms = NULL,
                          corr.se = NULL,
@@ -74,6 +75,16 @@ probsens.irr <- function(counts,
     if(!is.list(seca.parms))
         stop('Sensitivity of exposure classification among those with the outcome should be a list.')
     else seca.parms <- seca.parms
+    if((length(seca.parms) != 2) | (length(spca.parms) != 2))
+        stop('Check distribution parameters')
+    if((!is.null(seexp.parms) & length(seexp.parms) != 2) |
+       (!is.null(spexp.parms) & length(spexp.parms) != 2))
+        stop('Check distribution parameters')
+    if((length(seca.parms[[1]]) != 1) | (length(spca.parms[[1]]) != 1))
+        stop('Which distribution?')
+    if((!is.null(seexp.parms[[1]]) & length(seexp.parms[[1]]) != 1) |
+       (!is.null(spexp.parms[[1]]) & length(spexp.parms[[1]]) != 1))
+        stop('Which distribution?')
     if(!is.null(corr.se) && (seca.parms[[1]] == "constant" | seexp.parms[[1]] == "constant"))
         stop('No correlated distributions with constant values.')
     if(!is.null(corr.sp) && (spca.parms[[1]] == "constant" | spexp.parms[[1]] == "constant"))
@@ -111,6 +122,10 @@ probsens.irr <- function(counts,
         seca.parms <- list(seca.parms[[1]], c(seca.parms[[2]], c(0, 1)))
     if((seca.parms[[1]] == "constant" | seca.parms[[1]] == "uniform" | seca.parms[[1]] == "triangular" | seca.parms[[1]] == "trapezoidal") & !all(seca.parms[[2]] >= 0 & seca.parms[[2]] <= 1))
         stop('Sensitivity of exposure classification among those with the outcome should be between 0 and 1.')
+    if(seca.parms[[1]] == "beta" & length(seca.parms[[2]]) != 2)
+        stop('For beta distribution, please provide alpha and beta.')
+    if(seca.parms[[1]] == "beta" & (seca.parms[[2]][1] < 0 | seca.parms[[2]][2] < 0))
+        stop('Wrong arguments for your beta distribution. Alpha and Beta should be > 0.')
     
     if(!is.null(seexp.parms) & !is.list(seexp.parms))
         stop('Sensitivity of exposure classification among those without the outcome should be a list.')
@@ -153,6 +168,11 @@ probsens.irr <- function(counts,
         seexp.parms <- list(seexp.parms[[1]], c(seexp.parms[[2]], c(0, 1)))
     if(!is.null(seexp.parms) && (seexp.parms[[1]] == "constant" |seexp.parms[[1]] == "uniform" | seexp.parms[[1]] == "triangular" | seexp.parms[[1]] == "trapezoidal") & !all(seexp.parms[[2]] >= 0 & seexp.parms[[2]] <= 1))
         stop('Sensitivity of exposure classification among those without the outcome should be between 0 and 1.')
+    if(!is.null(seexp.parms) && seexp.parms[[1]] == "beta" && length(seexp.parms[[2]]) != 2)
+        stop('For beta distribution, please provide alpha and beta.')
+    if(!is.null(seexp.parms) && seexp.parms[[1]] == "beta" &&
+       (seexp.parms[[2]][1] < 0 | seexp.parms[[2]][2] < 0))
+        stop('Wrong arguments for your beta distribution. Alpha and Beta should be > 0.')
     
     if(!is.list(spca.parms))
         stop('Specificity of exposure classification among those with the outcome should be a list.')
@@ -190,6 +210,10 @@ probsens.irr <- function(counts,
         spca.parms <- list(spca.parms[[1]], c(spca.parms[[2]], c(0, 1)))
     if((spca.parms[[1]] == "constant" | spca.parms[[1]] == "uniform" | spca.parms[[1]] == "triangular" | spca.parms[[1]] == "trapezoidal") & !all(spca.parms[[2]] >= 0 & spca.parms[[2]] <= 1))
         stop('Specificity of exposure classification among those with the outcome should be between 0 and 1.')
+    if(spca.parms[[1]] == "beta" & length(spca.parms[[2]]) != 2)
+        stop('For beta distribution, please provide alpha and beta.')
+    if(spca.parms[[1]] == "beta" & (spca.parms[[2]][1] < 0 | spca.parms[[2]][2] < 0))
+        stop('Wrong arguments for your beta distribution. Alpha and Beta should be > 0.')
     
     if(!is.null(spexp.parms) & !is.list(spexp.parms))
         stop('Specificity of exposure classification among those without the outcome should be a list.')
@@ -232,6 +256,11 @@ probsens.irr <- function(counts,
         spexp.parms <- list(spexp.parms[[1]], c(spexp.parms[[2]], c(0, 1)))
     if(!is.null(spexp.parms) && (spexp.parms[[1]] == "constant" | spexp.parms[[1]] == "uniform" | spexp.parms[[1]] == "triangular" | spexp.parms[[1]] == "trapezoidal") & !all(spexp.parms[[2]] >= 0 & spexp.parms[[2]] <= 1))
         stop('Specificity of exposure classification among those without the outcome should be between 0 and 1.')
+    if(!is.null(spexp.parms) && spexp.parms[[1]] == "beta" && length(spexp.parms[[2]]) != 2)
+        stop('For beta distribution, please provide alpha and beta.')
+    if(!is.null(spexp.parms) && spexp.parms[[1]] == "beta" &&
+       (spexp.parms[[2]][1] < 0 | spexp.parms[[2]][2] < 0))
+        stop('Wrong arguments for your beta distribution. Alpha and Beta should be > 0.')
     
     if(!is.null(seexp.parms) & (is.null(spca.parms) | is.null(spexp.parms) |
                                 is.null(corr.se) | is.null(corr.sp)))
@@ -271,19 +300,6 @@ probsens.irr <- function(counts,
     uci.obs.irr <- (binom.test(a, a + b, conf.level = 1 - alpha)$conf.int[2] * d) /
         ((1 - binom.test(a, a + b, conf.level = 1 - alpha)$conf.int[2]) * c)
 
-    logitlog.dstr <- function(sesp) {
-        u <- runif(sesp[[1]])
-        w <- sesp[[2]] + sesp[[3]] * (log(u / (1 - u)))
-        p <- sesp[[4]] + (sesp[[5]] - sesp[[4]]) * exp(w) / (1 + exp(w))
-        return(p)
-    }
-    logitnorm.dstr <- function(sesp) {
-        u <- runif(sesp[[1]])
-        w <- sesp[[2]] + sesp[[3]] * qnorm(u)
-        p <- sesp[[4]] + (sesp[[5]] - sesp[[4]]) * exp(w) / (1 + exp(w))
-        return(p)
-    }
-    
     if (is.null(seexp.parms) & !is.null(spca.parms) & is.null(spexp.parms) &
         is.null(corr.se) & is.null(corr.sp)) {
         if (seca.parms[[1]] == "constant") {
@@ -303,7 +319,10 @@ probsens.irr <- function(counts,
             }
         if (seca.parms[[1]] == "logit-normal") {
             draws[, 1] <- logitnorm.dstr(seca)
-            }
+        }
+        if (seca.parms[[1]] == "beta") {
+            draws[, 1] <- do.call(rbeta, as.list(seca))
+        }
         draws[, 2] <- draws[, 1]
         if (spca.parms[[1]] == "constant") {
             draws[, 3] <- spca.parms[[2]]
@@ -323,6 +342,9 @@ probsens.irr <- function(counts,
         if (spca.parms[[1]] == "logit-normal") {
             draws[, 3] <- logitnorm.dstr(spca)
             }
+        if (spca.parms[[1]] == "beta") {
+            draws[, 3] <- do.call(rbeta, as.list(spca))
+        }
         draws[, 4] <- draws[, 3]
     } else {
         corr.draws[, 1:6] <- apply(corr.draws[, 1:6],
@@ -372,6 +394,12 @@ probsens.irr <- function(counts,
         seca.w <- seca.parms[[2]][1] + (seca.parms[[2]][2] * qnorm(corr.draws[, 7]))
         draws[, 1] <- seca.parms[[2]][3] + (seca.parms[[2]][4] - seca.parms[[2]][3]) * exp(seca.w) / (1 + exp(seca.w))
     }
+    if (seca.parms[[1]] == "beta") {
+        draws[, 1] <- qbeta(corr.draws[, 7]/(1 + corr.draws[, 7]),
+                            seca.parms[[2]][1],
+                            seca.parms[[2]][2])
+    }
+    
     if (seexp.parms[[1]] == "uniform") {
         draws[, 2] <- seexp.parms[[2]][2] -
             (seexp.parms[[2]][2] - seexp.parms[[2]][1]) * corr.draws[, 8]
@@ -404,6 +432,12 @@ probsens.irr <- function(counts,
         seexp.w <- seexp.parms[[2]][1] + (seexp.parms[[2]][2] * qnorm(corr.draws[, 8]))
         draws[, 2] <- seexp.parms[[2]][3] + (seexp.parms[[2]][4] - seexp.parms[[2]][3]) * exp(seexp.w) / (1 + exp(seexp.w))
     }
+    if (seexp.parms[[1]] == "beta") {
+        draws[, 2] <- qbeta(corr.draws[, 8]/(1 + corr.draws[, 8]),
+                            seexp.parms[[2]][1],
+                            seexp.parms[[2]][2])
+    }
+    
     if (spca.parms[[1]] == "uniform") {
         draws[, 3] <- spca.parms[[2]][2] -
             (spca.parms[[2]][2] - spca.parms[[2]][1]) * corr.draws[, 9]
@@ -436,6 +470,12 @@ probsens.irr <- function(counts,
         spca.w <- spca.parms[[2]][1] + (spca.parms[[2]][2] * qnorm(corr.draws[, 9]))
         draws[, 3] <- spca.parms[[2]][3] + (spca.parms[[2]][4] - spca.parms[[2]][3]) * exp(spca.w) / (1 + exp(spca.w))
     }
+    if (spca.parms[[1]] == "beta") {
+        draws[, 3] <- qbeta(corr.draws[, 9]/(1 + corr.draws[, 9]),
+                            spca.parms[[2]][1],
+                            spca.parms[[2]][2])
+    }
+    
     if (spexp.parms[[1]] == "uniform") {
         draws[, 4] <- spexp.parms[[2]][2] -
             (spexp.parms[[2]][2] - spexp.parms[[2]][1]) * corr.draws[, 10]
@@ -468,6 +508,11 @@ probsens.irr <- function(counts,
         spexp.w <- spexp.parms[[2]][1] + (spexp.parms[[2]][2] * qnorm(corr.draws[, 10]))
         draws[, 4] <- spexp.parms[[2]][3] + (spexp.parms[[2]][4] - spexp.parms[[2]][3]) * exp(spexp.w) / (1 + exp(spexp.w))
     }
+    if (spexp.parms[[1]] == "beta") {
+        draws[, 4] <- qbeta(corr.draws[, 10]/(1 + corr.draws[, 10]),
+                            spexp.parms[[2]][1],
+                            spexp.parms[[2]][2])
+    }
     }
     
     draws[, 11] <- runif(reps)
@@ -482,29 +527,34 @@ probsens.irr <- function(counts,
     draws[, 9] <- (draws[, 5]/(draws[, 5] + draws[, 7])) /
         (draws[, 6]/(draws[, 6] + draws[, 8]))
     
-    draws[, 9] <- ifelse(draws[, 5] < 1 |
-                             draws[, 6] < 1 |
-                                 draws[, 7] < 1 |
-                                     draws[, 8] < 1, NA, draws[, 9])
-    draws[, 9] <- ifelse(draws[, 2] < (c / (c + d)) |
-                             draws[, 4] < (d / (c + d)) |
-                                 draws[, 1] < (a / (a + b)) |
-                                     draws[, 3] < (b / (a + b)), NA, draws[, 9])
-    if(all(is.na(draws[, 9])))
+    draws[, 9] <- ifelse(draws[, 5] < 0 |
+                             draws[, 6] < 0 |
+                                 draws[, 7] < 0 |
+                                     draws[, 8] < 0, NA, draws[, 9])
+    if(all(is.na(draws[, 9]))) {
         warning('Prior Se/Sp distributions lead to all negative adjusted counts.')
+        neg_warn <- "Prior Se/Sp distributions lead to all negative adjusted counts."
+    } else neg_warn <- NULL
     if (discard) {
-        if(sum(is.na(draws[, 9])) > 0)
+        if(sum(is.na(draws[, 9])) > 0) {
             message('Chosen prior Se/Sp distributions lead to ',
                     sum(is.na(draws[, 9])),
                     ' negative adjusted counts which were discarded.')
+            discard_mess <- c(paste('Chosen prior Se/Sp distributions lead to ',
+                                    sum(is.na(draws[, 9])),
+                                    ' negative adjusted counts which were discarded.'))
+        } else discard_mess <- NULL
     }
     else {
         if(sum(is.na(draws[, 9])) > 0) {
             message('Chosen prior Se/Sp distributions lead to ',
                     sum(is.na(draws[, 9])),
                     ' negative adjusted counts which were set to zero.')
-        }
-        draws[, 9] <- ifelse(is.na(draws[, 9]), 0, draws[, 9])
+                discard_mess <- c(paste('Chosen prior Se/Sp distributions lead to ',
+                                        sum(is.na(draws[, 9])),
+                                        ' negative adjusted counts which were set to zero.'))
+            draws[, 9] <- ifelse(is.na(draws[, 9]), 0, draws[, 9])            
+        } else discard_mess <- NULL
     }
 
     draws[, 10] <- exp(log(draws[, 9]) -
@@ -535,7 +585,11 @@ probsens.irr <- function(counts,
     res <- list(obs.data = tab,
                 obs.measures = rmat, 
                 adj.measures = rmatc,
-                sim.df = as.data.frame(draws[, -11]))
-    class(res) <- c("episensr", "list")
+                sim.df = as.data.frame(draws[, -11]),
+                reps = reps,
+                fun = "probsens.irr",
+                warnings = neg_warn,
+                message = discard_mess)
+    class(res) <- c("episensr", "episensr.probsens", "list")
     res
 }
