@@ -10,26 +10,28 @@
 #' }
 #' @param pt A numeric vector of person-time at risk. If provided, \code{counts} must be a numeric vector of disease counts.
 #' @param reps Number of replications to run.
-#' @param prev.exp List defining the prevalence of exposure among the exposed. The first argument provides the probability distribution function (constant,uniform, triangular, trapezoidal, logit-logistic, or logit-normal) and the second its parameters as a vector. Logit-logistic and logit-normal distributions can be shifted by providing lower and upper bounds. Avoid providing these values if a non-shifted distribution is desired.
+#' @param prev.exp List defining the prevalence of exposure among the exposed. The first argument provides the probability distribution function (constant,uniform, triangular, trapezoidal, logit-logistic, logit-normal, or beta) and the second its parameters as a vector. Logit-logistic and logit-normal distributions can be shifted by providing lower and upper bounds. Avoid providing these values if a non-shifted distribution is desired.
 #' \enumerate{
-#' \item Constant; value,
-#' \item Uniform: min, max,
-#' \item Triangular: lower limit, upper limit, mode,
-#' \item Trapezoidal: min, lower mode, upper mode, max.
-#' \item Logit-logistic: location, scale, lower bound shift, upper bound shift,
-#' \item Logit-normal: location, scale, lower bound shift, upper bound shift.
+#' \item constant; value,
+#' \item uniform: min, max,
+#' \item triangular: lower limit, upper limit, mode,
+#' \item trapezoidal: min, lower mode, upper mode, max.
+#' \item logit-logistic: location, scale, lower bound shift, upper bound shift,
+#' \item logit-normal: location, scale, lower bound shift, upper bound shift,
+#' \item beta: alpha, beta.
 #' }
 #' @param prev.nexp List defining the prevalence of exposure among the unexposed.
 #' @param risk List defining the confounder-disease relative risk or the confounder-exposure odds ratio. The first argument provides the probability distribution function (constant,uniform, triangular, trapezoidal, log-logistic, or log-normal) and the second its parameters as a vector:
 #' \enumerate{
-#' \item Constant: value,
-#' \item Uniform: min, max,
-#' \item Triangular: lower limit, upper limit, mode,
-#' \item Trapezoidal: min, lower mode, upper mode, max.
-#' \item Log-logistic: shape, rate. Must be strictly positive,
-#' \item Log-normal: meanlog, sdlog. This is the mean and standard deviation on the log scale.
+#' \item constant: value,
+#' \item uniform: min, max,
+#' \item triangular: lower limit, upper limit, mode,
+#' \item trapezoidal: min, lower mode, upper mode, max.
+#' \item log-logistic: shape, rate. Must be strictly positive,
+#' \item log-normal: meanlog, sdlog. This is the mean and standard deviation on the log scale.
 #' }
 #' @param corr.p Correlation between the exposure-specific confounder prevalences.
+#' @param discard A logical scalar. In case of negative adjusted count, should the draws be discarded? If set to FALSE, negative counts are set to zero.
 #' @param alpha Significance level.
 #'
 #' @return A list with elements:
@@ -51,23 +53,24 @@
 #' risk = list("trapezoidal", c(2, 2.5, 3.5, 4.5)),
 #' corr.p = .8)
 #' @export
-#' @importFrom stats binom.test median quantile runif
+#' @importFrom stats binom.test median quantile runif rbeta qbeta
 probsens.irr.conf <- function(counts,
                          pt = NULL,
                          reps = 1000,
                          prev.exp = list(dist = c("constant", "uniform",
                                                "triangular", "trapezoidal",
-                                               "logit-logistic", "logit-normal"),
+                                               "logit-logistic", "logit-normal", "beta"),
                              parms = NULL),
                          prev.nexp = list(dist = c("constant", "uniform",
                                                "triangular", "trapezoidal",
-                                               "logit-logistic", "logit-normal"),
+                                               "logit-logistic", "logit-normal", "beta"),
                              parms = NULL),
                          risk = list(dist = c("constant", "uniform", "triangular",
                                           "trapezoidal", "log-logistic",
                                                "log-normal"),
                               parms = NULL),
                          corr.p = NULL,
+                         discard = TRUE,
                          alpha = 0.05){
     if(reps < 1)
         stop(paste("Invalid argument: reps = ", reps))
@@ -80,6 +83,11 @@ probsens.irr.conf <- function(counts,
     if(!is.list(prev.exp))
         stop('Prevalence of exposure among the exposed should be a list.')
     else prev.exp <- prev.exp
+    if((length(prev.exp) != 2) | (length(prev.nexp) != 2) | (length(risk) != 2))
+        stop('Check distribution parameters.')
+    if((length(prev.exp[[1]]) != 1) | (length(prev.nexp[[1]]) != 1) |
+       (length(risk[[1]]) != 1))
+        stop('Which distribution?')
     if(!is.null(corr.p) && (prev.exp[[1]] == "constant" | prev.nexp[[1]] == "constant"))
         stop('No correlated distributions with constant values.')
     if(prev.exp[[1]] == "constant" & length(prev.exp[[2]]) != 1)
@@ -115,6 +123,11 @@ probsens.irr.conf <- function(counts,
         prev.exp <- list(prev.exp[[1]], c(prev.exp[[2]], c(0, 1)))
     if((prev.exp[[1]] == "constant" | prev.exp[[1]] == "uniform" | prev.exp[[1]] == "triangular" | prev.exp[[1]] == "trapezoidal") & !all(prev.exp[[2]] >= 0 & prev.exp[[2]] <= 1))
         stop('Prevalence should be between 0 and 1.')
+    if(!is.null(prev.exp) && prev.exp[[1]] == "beta" && length(prev.exp[[2]]) != 2)
+        stop('For beta distribution, please provide alpha and beta.')
+    if(!is.null(prev.exp) && prev.exp[[1]] == "beta" &&
+       (prev.exp[[2]][1] < 0 | prev.exp[[2]][2] < 0))
+        stop('Wrong arguments for your beta distribution. Alpha and Beta should be > 0.')
     
     if(!is.list(prev.nexp))
         stop('Prevalence of exposure among the non-exposed should be a list.')
@@ -152,6 +165,11 @@ probsens.irr.conf <- function(counts,
         prev.nexp <- list(prev.nexp[[1]], c(prev.nexp[[2]], c(0, 1)))
     if((prev.nexp[[1]] == "constant" | prev.nexp[[1]] == "uniform" | prev.nexp[[1]] == "triangular" | prev.nexp[[1]] == "trapezoidal") & !all(prev.nexp[[2]] >= 0 & prev.nexp[[2]] <= 1))
         stop('Prevalence should be between 0 and 1.')
+    if(!is.null(prev.nexp) && prev.nexp[[1]] == "beta" && length(prev.nexp[[2]]) != 2)
+        stop('For beta distribution, please provide alpha and beta.')
+    if(!is.null(prev.nexp) && prev.nexp[[1]] == "beta" &&
+       (prev.nexp[[2]][1] < 0 | prev.nexp[[2]][2] < 0))
+        stop('Wrong arguments for your beta distribution. Alpha and Beta should be > 0.')
     
     if(!is.list(risk))
         stop('Risk should be a list.')
@@ -210,19 +228,6 @@ probsens.irr.conf <- function(counts,
     uci.obs.irr <- (binom.test(a, a + b, conf.level = 1 - alpha)$conf.int[2] * d) /
         ((1 - binom.test(a, a + b, conf.level = 1 - alpha)$conf.int[2]) * c)
 
-    logitlog.dstr <- function(sesp) {
-        u <- runif(sesp[[1]])
-        w <- sesp[[2]] + sesp[[3]] * (log(u / (1 - u)))
-        p <- sesp[[4]] + (sesp[[5]] - sesp[[4]]) * exp(w) / (1 + exp(w))
-        return(p)
-    }
-    logitnorm.dstr <- function(sesp) {
-        u <- runif(sesp[[1]])
-        w <- sesp[[2]] + sesp[[3]] * qnorm(u)
-        p <- sesp[[4]] + (sesp[[5]] - sesp[[4]]) * exp(w) / (1 + exp(w))
-        return(p)
-    }
-    
     if (is.null(corr.p)) {
         if (prev.exp[[1]] == "constant") {
             draws[, 1] <- prev.exp[[2]]
@@ -242,6 +247,9 @@ probsens.irr.conf <- function(counts,
         if (prev.exp[[1]] == "logit-normal") {
             draws[, 1] <- logitnorm.dstr(p1)
             }
+        if (prev.exp[[1]] == "beta") {
+            draws[, 1] <- do.call(rbeta, as.list(p1))
+            }
         if (prev.nexp[[1]] == "constant") {
             draws[, 2] <- prev.nexp[[2]]
         }
@@ -260,6 +268,9 @@ probsens.irr.conf <- function(counts,
         if (prev.nexp[[1]] == "logit-normal") {
             draws[, 2] <- logitnorm.dstr(p0)
             }
+        if (prev.nexp[[1]] == "beta") {
+            draws[, 2] <- do.call(rbeta, as.list(p0))
+           }
     } else {
         corr.draws[, 1:3] <- apply(corr.draws[, 1:3],
                                    2,
@@ -304,6 +315,12 @@ probsens.irr.conf <- function(counts,
         pexp.w <- prev.exp[[2]][1] + (prev.exp[[2]][2] * qnorm(corr.draws[, 4]))
         draws[, 1] <- prev.exp[[2]][3] + (prev.exp[[2]][4] - prev.exp[[2]][3]) * exp(pexp.w) / (1 + exp(pexp.w))
     }
+    if (prev.exp[[1]] == "beta") {
+        draws[, 1] <- qbeta(corr.draws[, 4]/(1 + corr.draws[, 4]),
+                            prev.exp[[2]][1],
+                            prev.exp[[2]][2])
+    }
+    
     if (prev.nexp[[1]] == "uniform") {
         draws[, 2] <- prev.nexp[[2]][2] -
             (prev.nexp[[2]][2] - prev.nexp[[2]][1]) * corr.draws[, 5]
@@ -336,6 +353,11 @@ probsens.irr.conf <- function(counts,
         punexp.w <- prev.nexp[[2]][1] + (prev.nexp[[2]][2] * qnorm(corr.draws[, 5]))
         draws[, 2] <- prev.nexp[[2]][3] + (prev.nexp[[2]][4] - prev.nexp[[2]][3]) * exp(punexp.w) / (1 + exp(punexp.w))
     }
+    if (prev.nexp[[1]] == "beta") {
+        draws[, 2] <- qbeta(corr.draws[, 5]/(1 + corr.draws[, 5]),
+                            prev.nexp[[2]][1],
+                            prev.nexp[[2]][2])
+    }
     }
         
     if(risk[[1]] == "constant") {
@@ -374,18 +396,37 @@ probsens.irr.conf <- function(counts,
         ((draws[, 4] * draws[, 7] / draws[, 5]) +
              (draws[, 8] * draws[, 11] / draws[, 9]))
     
-    draws[, 12] <- ifelse(draws[, 4] < 1 |
-                             draws[, 5] < 1 |
-                                 draws[, 7] < 1 |
-                                     draws[, 8] < 1 |
-                                         draws[, 11] < 1, NA, draws[, 12])
+    draws[, 12] <- ifelse(draws[, 4] < 0 |
+                             draws[, 5] < 0 |
+                                 draws[, 7] < 0 |
+                                     draws[, 8] < 0 |
+                                         draws[, 11] < 0, NA, draws[, 12])
 
-    if(all(is.na(draws[, 12])))
+    if(all(is.na(draws[, 12]))) {
         warning('Prior prevalence distributions lead to all negative adjusted values.')
-    if(sum(is.na(draws[, 12])) > 0)
-        message('Chosen prior prevalence distributions lead to ',
-                sum(is.na(draws[, 12])),
-                ' negative adjusted values which were discarded.')
+        neg_warn <- "Prior Se/Sp distributions lead to all negative adjusted counts."
+    } else neg_warn <- NULL
+    if (discard) {
+        if(sum(is.na(draws[, 12])) > 0) {
+            message('Chosen prior prevalence distributions lead to ',
+                    sum(is.na(draws[, 12])),
+                    ' negative adjusted values which were discarded.')
+            discard_mess <- c(paste('Chosen prior Se/Sp distributions lead to ',
+                                    sum(is.na(draws[, 12])),
+                                    ' negative adjusted counts which were discarded.'))
+        } else discard_mess <- NULL
+    }
+    else {
+        if(sum(is.na(draws[, 12])) > 0) {
+            message('Chosen prior Se/Sp distributions lead to ',
+                    sum(is.na(draws[, 12])),
+                    ' negative adjusted counts which were set to zero.')
+                discard_mess <- c(paste('Chosen prior Se/Sp distributions lead to ',
+                                        sum(is.na(draws[, 12])),
+                                        ' negative adjusted counts which were set to zero.'))
+            draws[, 12] <- ifelse(is.na(draws[, 12]), 0, draws[, 12])            
+        } else discard_mess <- NULL
+    }
 
     draws[, 14] <- exp(log(draws[, 12]) -
                            qnorm(draws[, 13]) *
@@ -415,7 +456,11 @@ probsens.irr.conf <- function(counts,
     res <- list(obs.data = tab,
                 obs.measures = rmat, 
                 adj.measures = rmatc,
-                sim.df = as.data.frame(draws[, -13]))
-    class(res) <- c("episensr", "list")
+                sim.df = as.data.frame(draws[, -13]),
+                reps = reps,
+                fun = "probsens.irr.conf",
+                warnings = neg_warn,
+                message = discard_mess)
+    class(res) <- c("episensr", "episensr.probsens", "list")
     res
 }
